#[non_exhaustive]pub struct CheckpointSummary {
pub digest: Option<Digest>,
pub bcs: Option<BcsData>,
}Expand description
A header for a checkpoint on the IOTA blockchain.
On the IOTA network, checkpoints define the history of the blockchain. They are quite similar to the concept of blocks used by other blockchains like Bitcoin or Ethereum. The IOTA blockchain, however, forms checkpoints after transaction execution has already happened to provide a certified history of the chain, instead of being formed before execution.
Checkpoints commit to a variety of state, including but not limited to:
- The hash of the previous checkpoint.
- The set of transaction digests, their corresponding effects digests, as well as the set of user signatures that authorized its execution.
- The objects produced by a transaction.
- The set of live objects that make up the current state of the chain.
- On epoch transitions, the next validator committee.
CheckpointSummarys themselves don’t directly include all of the previous information but they
are the top-level type by which all the information is committed to transitively via cryptographic
hashes included in the summary. CheckpointSummarys are signed and certified by a quorum of
the validator committee in a given epoch to allow verification of the chain’s state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.digest: Option<Digest>The digest of this CheckpointSummary.
bcs: Option<BcsData>This CheckpointSummary serialized as BCS.
Implementations
Sourceimpl CheckpointSummary
impl CheckpointSummary
pub const DIGEST_FIELD: &'static MessageField
pub const BCS_FIELD: &'static MessageField
Sourceimpl CheckpointSummary
impl CheckpointSummary
Sourcepub fn digest(&self) -> Result<Digest, TryFromProtoError>
pub fn digest(&self) -> Result<Digest, TryFromProtoError>
Get the digest of this checkpoint summary.
Read mask: "checkpoint.summary.digest" (see
CHECKPOINT_SUMMARY_DIGEST).
Sourcepub fn summary(&self) -> Result<CheckpointSummary, TryFromProtoError>
pub fn summary(&self) -> Result<CheckpointSummary, TryFromProtoError>
Deserialize the checkpoint summary from BCS.
Read mask: "checkpoint.summary.bcs" (see
CHECKPOINT_SUMMARY_BCS).